# -*- coding: utf-8 -*-
"""
Esse script utiliza a classe MLPClassifier do 
pacote Sci-Kit Learn para classificar a base de dados
Iris.

@author: jmarcos
"""
from sklearn import datasets
from sklearn.neural_network import MLPClassifier
from matplotlib import pyplot as plt
import numpy as np

iris = datasets.load_iris()

# Número de elementos dados da base.
N = 150

# Metade da base será utilizada para treinamento.
Meio_N = 75

# Ordena os índices dos dados aleatoriamente.
ordem_elementos = np.random.permutation(N)

# Conjunto de dados de treinamento (pelo índice).
Treinamento = ordem_elementos[:Meio_N]

# Conjunto de dados de teste (pelo índice)
Teste = ordem_elementos[Meio_N:]

# Armazena os rótulos originais para posterior comparação.
classificacao_original = iris['target'][Teste]

# Constroi a rede neural com determinada arquitetura.
# Arquitetura inicial: 4x2x3
clf = MLPClassifier(solver='lbfgs', alpha=1e-5, hidden_layer_sizes=(4,5,3), random_state=1)

# Treina a rede com metade dos dados de forma aleatória - Dados de Treinamento.
clf.fit(iris['data'][Treinamento], iris['target'][Treinamento])

# Testa a rede sobre a outra metade dos dados - Dados de Teste.
classificacao = clf.predict(iris['data'][Teste])

# Compara os resultados originais com os preditos pela rede e calcula o erro
# percentual.
erro = (np.count_nonzero(classificacao - classificacao_original)/75.0)*100
print(erro)

#features = iris["data"]
#feature_names = iris["feature_names"]
#target = iris["target"]
#
#for t,marker,c in zip(range(3), ">ox", "rgb"):
#    plt.scatter(features[target == t,0],
#                features[target == t,1],
#                marker = marker, c=c)


